@@ -120,13 +120,27 @@
 //!   - `"flatcase"`
 //!   - `"UPPERFLATCASE"`
 //! 
-//!   **Note**: For enums, the `rename_all` attribute is only effective for unit variants. 
+//!   **Note**: For enums, the `rename_all` attribute is only effective for unit variants.
 //!   Because the other variants always behave as if the `flatten` attribute of *serde* is applied.
 //! 
 //! - `#[rschema(unique_items)]`
 //! 
 //!   Indicates that the tuple struct has unique values.
 //! 
+//! - `#[rschema(defs)]`
+//! 
+//!   Define in `$defs` with an auto-generated name.
+//! 
+//!   **Note**: This uses `std::any::type_name()` to generate as unique a name as possible.
+//!   However, it is not guaranteed to be unique. 
+//! 
+//! - `#[rschema(defs = "name")]`
+//! 
+//!   Define in `$defs` with the given name.
+//! 
+//!   **Note**: Any name can be given, but if a name is duplicated, the definition is overwritten.
+//!   Therefore, it is recommended that do not use this for types that are published.
+//! 
 //! 
 //! ## Variant attributes
 //! 
@@ -185,6 +199,14 @@
 //! 
 //!   Renames the field name with the given name.
 //! 
+//! - `#[rschema(alt = "path")]`
+//! 
+//!   This is very similar to the serde's `remote` attribute. But it does not check that all the fields in the definition you provided match those in the external type.
+//! 
+//!   If use external types, it probably does not implement `Schematic`. In such a case, you need to give the schema information instead by specifying another type that implements `Schematic`.
+//! 
+//!   **Note**: Rschema does not pre-implement the `Schematic` for types provided by non-standard crates. It is to prevent cyclic package dependency, in the case that external crates come to implement `Schematic` in the future.
+//! 
 //! - `#[rschema(skip)]`
 //! 
 //!   Skip not to include in schema.
@@ -202,7 +224,7 @@
 //! 
 //! - `#[rschema(pattern = "regular expressions")]`
 //! 
-//!   The regular expression to restrict a string. You should use a raw strings if necessary to avoid unnecessary escaping.
+//!   The regular expression to restrict a string. If necessary, you should use raw string literals to work around escaping.
 //! 
 //! - `#[rschema(format = "format")]`
 //! 
@@ -259,6 +281,8 @@
 pub use rschema_core::{
     AdditionalProperties,
     ArrayKeys,
+    Definitions,
+    DefinitionsMap,
     Draft,
     EnumKeys,
     Error,
