@@ -5,22 +5,19 @@ use rschema::{
     Schematic,
 };
 
+#[derive(Debug, Schematic)]
+#[rschema(unique_items)]
+struct TupleStruct(u32, u32);
+
 #[derive(Debug, Schematic)]
 enum Enum {
     UnitVariant,
 
     EmptyTupleVariant(),
 
-    TupleVariant(
-        #[rschema(
-            title = "i32",
-            minimum = 0,
-            maximum = 100,
-        )]
-        i32,
+    NewTypeVariant(i32),
 
-        String,
-    ),
+    TupleVariant(String, bool),
 
     StructVariant {
         #[rschema(title = "i32")]
@@ -29,18 +26,24 @@ enum Enum {
 }
 
 #[derive(Debug, Schematic)]
-struct ArrayProperties {
+struct ArrayProperties<'a> {
     #[rschema(title = "[i32; 3]")]
-    prop_array3: [i32; 3],
+    prop_sized_array: [i32; 3],
 
-    // #[rschema(title = "&[i32]")]
-    // prop_ref_array: &'a [i32],
+    #[rschema(title = "&[i32]")]
+    prop_array: &'a [i32],
 
     #[rschema(title = "Vec<i32>")]
     prop_vec: Vec<i32>,
 
     #[rschema(title = "(i32, String, bool)")]
-    prop_tuple3: (i32, String, bool),
+    prop_tuple: (i32, String, bool),
+
+    #[rschema(
+        title = "TupleStruct",
+        unique_items,
+    )]
+    prop_unique_tuple_struct: TupleStruct,
 
     #[rschema(title = "Vec<Enum>")]
     prop_vec_enum: Vec<Enum>,
@@ -55,14 +58,14 @@ struct ArrayProperties {
 }
 
 #[test]
-fn it_generates_array_schema() -> rschema::Result<()> {
+fn it_tests_array_properties() -> rschema::Result<()> {
     let schema_str = Schema::new::<ArrayProperties>("Array Properties")
         .to_string_pretty()?;
     let schema_str2 = r#"{
   "title": "Array Properties",
   "type": "object",
   "properties": {
-    "prop_array3": {
+    "prop_sized_array": {
       "title": "[i32; 3]",
       "type": "array",
       "items": {
@@ -71,6 +74,13 @@ fn it_generates_array_schema() -> rschema::Result<()> {
       "minItems": 3,
       "maxItems": 3
     },
+    "prop_array": {
+      "title": "&[i32]",
+      "type": "array",
+      "items": {
+        "type": "number"
+      }
+    },
     "prop_vec": {
       "title": "Vec<i32>",
       "type": "array",
@@ -78,7 +88,7 @@ fn it_generates_array_schema() -> rschema::Result<()> {
         "type": "number"
       }
     },
-    "prop_tuple3": {
+    "prop_tuple": {
       "title": "(i32, String, bool)",
       "type": "array",
       "items": [
@@ -95,6 +105,21 @@ fn it_generates_array_schema() -> rschema::Result<()> {
       "minItems": 3,
       "maxItems": 3
     },
+    "prop_unique_tuple_struct": {
+      "title": "TupleStruct",
+      "type": "array",
+      "items": [
+        {
+          "type": "number"
+        },
+        {
+          "type": "number"
+        }
+      ],
+      "minItems": 2,
+      "maxItems": 2,
+      "uniqueItems": true
+    },
     "prop_vec_enum": {
       "title": "Vec<Enum>",
       "type": "array",
@@ -106,17 +131,17 @@ fn it_generates_array_schema() -> rschema::Result<()> {
             "minItems": 0,
             "maxItems": 0
           },
+          {
+            "type": "number"
+          },
           {
             "type": "array",
             "items": [
               {
-                "title": "i32",
-                "type": "number",
-                "minimum": 0,
-                "maximum": 100
+                "type": "string"
               },
               {
-                "type": "string"
+                "type": "boolean"
               }
             ],
             "minItems": 2,
