@@ -9,18 +9,21 @@ use rschema::{
 enum Enum {
     EmptyTupleVariant(),
 
+    NewTypeVariant(i32),
+
     TupleVariant(
         #[rschema(
-            minimum = 0,
-            maximum = 100,
+            title = "value",
+            format = "myformat",
         )]
-        i32,
-
         String,
+
+        bool,
     ),
 
+    #[rschema(additional_properties)]
     StructVariant {
-        #[rschema(title = "i32")]
+        #[rschema(title = "value")]
         value: i32,
     }
 }
@@ -32,14 +35,6 @@ enum EnumUnits {
     UnitVariant3,
 }
 
-#[derive(Debug, Schematic)]
-#[rschema(rename_all = "camelCase")]
-enum EnumUnitsRenamed {
-    UnitVariantX,
-    UnitVariantY,
-    UnitVariantZ,
-}
-
 #[derive(Debug, Schematic)]
 struct EnumProperties {
     #[rschema(title = "Enum")]
@@ -47,13 +42,10 @@ struct EnumProperties {
 
     #[rschema(title = "EnumUnits")]
     prop_enum_units: EnumUnits,
-
-    #[rschema(title = "EnumUnitsRenamed")]
-    prop_enum_units_renamed: EnumUnitsRenamed,
 }
 
 #[test]
-fn it_generates_enum_schema() -> rschema::Result<()> {
+fn it_tests_enum_properties() -> rschema::Result<()> {
     let schema_str = Schema::new::<EnumProperties>("Enum Properties")
         .to_string_pretty()?;
     let schema_str2 = r#"{
@@ -69,16 +61,19 @@ fn it_generates_enum_schema() -> rschema::Result<()> {
           "minItems": 0,
           "maxItems": 0
         },
+        {
+          "type": "number"
+        },
         {
           "type": "array",
           "items": [
             {
-              "type": "number",
-              "minimum": 0,
-              "maximum": 100
+              "title": "value",
+              "type": "string",
+              "format": "myformat"
             },
             {
-              "type": "string"
+              "type": "boolean"
             }
           ],
           "minItems": 2,
@@ -88,11 +83,11 @@ fn it_generates_enum_schema() -> rschema::Result<()> {
           "type": "object",
           "properties": {
             "value": {
-              "title": "i32",
+              "title": "value",
               "type": "number"
             }
           },
-          "additionalProperties": false
+          "additionalProperties": true
         }
       ]
     },
@@ -104,15 +99,6 @@ fn it_generates_enum_schema() -> rschema::Result<()> {
         "UnitVariant2",
         "UnitVariant3"
       ]
-    },
-    "prop_enum_units_renamed": {
-      "title": "EnumUnitsRenamed",
-      "type": "string",
-      "enum": [
-        "unitVariantX",
-        "unitVariantY",
-        "unitVariantZ"
-      ]
     }
   },
   "additionalProperties": false
