@@ -5,6 +5,11 @@ use rschema::{
     Schematic,
 };
 
+use std::collections::{
+    HashMap,
+    HashSet,
+};
+
 #[derive(Debug, Schematic)]
 struct OtherProperties {
     #[rschema(title = "Option<i32>")]
@@ -12,10 +17,16 @@ struct OtherProperties {
 
     #[rschema(title = "Box<i32>")]
     prop_box: Box<i32>,
+
+    #[rschema(title = "HashMap<String, i32>")]
+    prop_hashmap: HashMap<String, i32>,
+
+    #[rschema(title = "HashSet<i32>")]
+    prop_hashset: HashSet<i32>,
 }
 
 #[test]
-fn it_generates_other_schema() -> rschema::Result<()> {
+fn it_tests_other_properties() -> rschema::Result<()> {
     let schema_str = Schema::new::<OtherProperties>("Other Properties")
         .to_string_pretty()?;
     let schema_str2 = r#"{
@@ -36,6 +47,22 @@ fn it_generates_other_schema() -> rschema::Result<()> {
     "prop_box": {
       "title": "Box<i32>",
       "type": "number"
+    },
+    "prop_hashmap": {
+      "title": "HashMap<String, i32>",
+      "type": "object",
+      "properties": {},
+      "additionalProperties": {
+        "type": "number"
+      }
+    },
+    "prop_hashset": {
+      "title": "HashSet<i32>",
+      "type": "array",
+      "items": {
+        "type": "number"
+      },
+      "uniqueItems": true
     }
   },
   "additionalProperties": false
